import { ITransitGatewayAttachment } from './transit-gateway-attachment';
import { ITransitGatewayRouteTable } from './transit-gateway-route-table';
import { Construct } from 'constructs';
import { ITransitGatewayAssociation, TransitGatewayAssociationBase } from './transit-gateway-association';
/**
 * Represents a Transit Gateway Route Table Association.
 */
export interface ITransitGatewayRouteTableAssociation extends ITransitGatewayAssociation {
}
/**
 * Common properties for a Transit Gateway Route Table Association.
 */
export interface TransitGatewayRouteTableAssociationProps {
    /**
     * The ID of the transit gateway route table association.
     */
    readonly transitGatewayVpcAttachment: ITransitGatewayAttachment;
    /**
     * The ID of the transit gateway route table association.
     */
    readonly transitGatewayRouteTable: ITransitGatewayRouteTable;
    /**
     * Physical name of this association.
     *
     * @default - Assigned by CloudFormation.
     */
    readonly transitGatewayRouteTableAssociationName?: string;
}
/**
 * Create a Transit Gateway Route Table Association.
 *
 * @resource AWS::EC2::TransitGatewayRouteTableAssociation
 */
export declare class TransitGatewayRouteTableAssociation extends TransitGatewayAssociationBase {
    /**
     * The ID of the transit gateway route table association.
     */
    readonly transitGatewayAssociationId: string;
    constructor(scope: Construct, id: string, props: TransitGatewayRouteTableAssociationProps);
}
