import { IResource, Resource } from 'aws-cdk-lib/core';
import { Construct } from 'constructs';
import { ITransitGatewayAttachment } from './transit-gateway-attachment';
import { ITransitGatewayRouteTable } from './transit-gateway-route-table';
/**
 * Represents a Transit Gateway Route Table Propagation.
 */
export interface ITransitGatewayRouteTablePropagation extends IResource {
    /**
     * The ID of the transit gateway route table propagation.
     * @attribute
     */
    readonly transitGatewayRouteTablePropagationId: string;
}
/**
 * Common properties for a Transit Gateway Route Table Propagation.
 */
export interface TransitGatewayRouteTablePropagationProps {
    /**
     * The ID of the transit gateway route table propagation.
     */
    readonly transitGatewayVpcAttachment: ITransitGatewayAttachment;
    /**
     * The ID of the transit gateway route table propagation.
     */
    readonly transitGatewayRouteTable: ITransitGatewayRouteTable;
    /**
     * Physical name of this propagation.
     *
     * @default - Assigned by CloudFormation.
     */
    readonly transitGatewayRouteTablePropagationName?: string;
}
/**
 * Create a Transit Gateway Route Table Propagation.
 *
 * @resource AWS::EC2::TransitGatewayRouteTablePropagation
 */
export declare class TransitGatewayRouteTablePropagation extends Resource implements ITransitGatewayRouteTablePropagation {
    /**
     * The ID of the transit gateway route table propagation.
     */
    readonly transitGatewayRouteTablePropagationId: string;
    constructor(scope: Construct, id: string, props: TransitGatewayRouteTablePropagationProps);
}
